@@ -1,5 +1,5 @@
-
-if __name__ == '__main__':
+if __name__ == "__main__":
     from .installer import main
+
     retval = main()
     exit(retval)
